import axios from 'axios'
import * as config from '../constants/config';

export default{
    isMobile(window){
        let isMobile = {
            Android() {
                return window.navigator.userAgent.match(/Android/i);
            },
            BlackBerry() {
                return window.navigator.userAgent.match(/BlackBerry/i);
            },
            iOS() {
                return window.navigator.userAgent.match(/iPhone|iPad|iPod/i);
            },
            Opera() {
                return window.navigator.userAgent.match(/Opera Mini/i);
            },
            Windows() {
                return window.navigator.userAgent.match(/IEMobile/i) || window.navigator.userAgent.match(/WPDesktop/i);
            },
            any() {
                return (isMobile.Android() || isMobile.BlackBerry() || isMobile.iOS() || isMobile.Opera() || isMobile.Windows() || window.innerWidth < 767);
            }
        };
        return isMobile.any();
    },
    isNullOrUndefined(str){
        return str == null || str == undefined;
    },
    getScrollOffsets(document, window) {
        var doc = document, w = window;
        var x, y, docEl;
        
        if ( typeof w.pageYOffset === 'number' ) {
            x = w.pageXOffset;
            y = w.pageYOffset;
        } else {
            docEl = (doc.compatMode && doc.compatMode === 'CSS1Compat')?
                    doc.documentElement: doc.body;
            x = docEl.scrollLeft;
            y = docEl.scrollTop;
        }
        return {x:x, y:y};
    },
    openSubMenu(id){
        document.getElementById(id).style.width = "250px";
        document.getElementById(id).style.position = "absolute";
    },
    closeSubMenu(id){
        document.getElementById(id).style.width = "0px";
    },
    async getMeta(params, defaut, groupe = 1, byId = false, id = 0){
        
        if (!byId){
            var slug = "";
            if (params.length > 0) slug = params[params.length - 1];
            var dbMeta = (await axios.get(config.apiUrl + '/getSEOBySlug/' + groupe + '/' + slug, {})).data;
        } else {
            var dbMeta = (await axios.get(config.apiUrl + '/getSEOById/' + id, {})).data;
        }
        
        if (dbMeta.length > 0){
            dbMeta = dbMeta[0];
            if (dbMeta.title) defaut.title = dbMeta.title;
            else if (dbMeta.name) defaut.title = dbMeta.name;
            if (dbMeta.description) defaut.description = dbMeta.description;
            if (dbMeta.keywords) defaut.keywords = dbMeta.keywords;
            if (dbMeta.h1) defaut.h1 = dbMeta.h1;
            else if (dbMeta.name) defaut.h1 = dbMeta.name;
            
            if (dbMeta.h2) defaut.h2 = dbMeta.h2;

            if (dbMeta.h3) defaut.h3 = dbMeta.h3;

            if (dbMeta.h4) defaut.h4 = dbMeta.h4;

            if (dbMeta.h5) defaut.h5 = dbMeta.h5;

            if (dbMeta.h6) defaut.h6 = dbMeta.h6;

            defaut.ext_p_h1 = dbMeta.ext_p_h1;
            defaut.ext_h2 = dbMeta.ext_h2;
            defaut.ext_p_h2 = dbMeta.ext_p_h2;
            defaut.ext_h22 = dbMeta.ext_h22;
            defaut.ext_p_h22 = dbMeta.ext_p_h22;
        }
        return defaut;
    },

    async getEncart(slug){
        var allData = (await axios.get(config.apiUrl + '/getCategoriesByNiveau/' + slug, {})).data;
        return allData;
    },
    
    uploadFile(file, folder){
        const mb = file.size/1024/1024;
        return new Promise((resolve) => {
            if(mb > 1.6){
                alert(`Veuillez utiliser une image de taille inférieur à 1.6 Mb. La taille de votre image actuelle est de ${mb} Mb`)
                resolve(false);
            }
    
            let formData = new FormData();
            formData.append('filenames', file);
            formData.append('folderName', folder);
    
            axios.post(config.apiUrl + '/uploadFile', formData, {headers: {'Content-Type': 'multipart/form-data'}}).then(_ => {
                resolve(true);
            }, _ => {
                resolve(false);
            })
        })        
    },
    showSpinner(open = true){
        const spinner = document.getElementById('my-spinner');
        if(!open)
            if (spinner) spinner.style.display = "none";
        else
            if (spinner) spinner.style.display = "block"
    },
    setUrl(url){
        if (url){
            if(url.indexOf('http://') == -1 && url.indexOf('https://') == -1)
                return 'http://'+url;
            else  
                return url;
        } else {
            return "";
        }
        
    },
    async formatToSlug(str){
           var ret = "";
            await axios.get(config.apiUrl + '/formatToSlug/' + str, {}).then(retour => {
                ret = retour.data;
            });
            return ret; 
        
    },
    async getCategoriesCanonical(str){
        var ret = "";
         await axios.get(config.apiUrl + '/getCategoriesCanonical/' + str, {}).then(retour => {
             ret = retour.data;
         });
         return ret; 
     
    },
    async checkAdminSession(){
        if (!sessionStorage.getItem("u")) return 0;

        return await axios.get(config.apiUrl + '/checkAdminSession/' + sessionStorage.getItem("u"), {}).data;
    },

    async checkCategory(slug){
        console.log(config.apiUrl + '/checkCategory/' + slug);
        var nb = (await axios.get(config.apiUrl + '/checkCategory/' + slug, {})).data;
        console.log(nb);
        return (nb == 0 || nb == '' ? false : true);
        //return true;
    },
    async getCinemaDetail(slug){
        //var allData = (await axios.get(config.apiUrl + '/getCategoriesByNiveau/' + slug, {})).data;
        var allData = (await axios.get(config.apiUrl + '/getCineBySlug/0/' + slug, {})).data[0];
        return allData;
    },
    async getFilmPlusCommenter(){
        //var allData = (await axios.get(config.apiUrl + '/getCategoriesByNiveau/' + slug, {})).data;
        var allData = (await axios.get(config.apiUrl + '/getFilmPlusCommenter', {})).data;
        return allData;
    },
    async getAllNews(){
        //var allData = (await axios.get(config.apiUrl + '/getCategoriesByNiveau/' + slug, {})).data;
        var allData = (await axios.get(config.apiUrl + '/getNews/0/5', {})).data;
        return allData;
    },
    async getAvantPremiere(){
        //var allData = (await axios.get(config.apiUrl + '/getCategoriesByNiveau/' + slug, {})).data;
        var allData = (await axios.get(config.apiUrl + '/getAvantPremiere', {})).data;
        return allData;
    },
    async getNewURL(oldURL, table){
        //var allData = (await axios.get(config.apiUrl + '/getCategoriesByNiveau/' + slug, {})).data;
        var allData = (await axios.get(config.apiUrl + '/getNewURL/' + table + '/' + oldURL, {})).data;
        return allData;
    },
    async getNewURLCateg(oldURL, table){
        //var allData = (await axios.get(config.apiUrl + '/getCategoriesByNiveau/' + slug, {})).data;
        var data = {
            table: table,
            oldURL: oldURL
        };
        var allData = (await axios.post(config.apiUrl + '/getNewURLCateg', {data: JSON.stringify(data)})).data;
        return allData;
    },
    async getAllCategData(data){
        var allData = (await axios.post(config.apiUrl + '/getAllCategData', {data: JSON.stringify(data)})).data;
        return allData;
    },
    async setSlider(){
        var allData = (await axios.get(config.apiUrl + '/getSliders/accueil', {})).data;
        return allData;
    }
}